from setuptools import setup

setup(
    name='bizdates',
    version='1.0.0',    
    description='A Python package for working with business dates',
    url='',
    author='Paul Gray',
    author_email='',
    license='BSD 2-clause',
    packages=['bizdates'],
    install_requires=['datetime'],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)